/*
**  CREAINDX.SQL
**  
**  Create ALL the NON-PK indexes.  The PK indexes are created by DRI.
**
**  Drop the old indexes first.
**
**  Don't forget to say 'USE credit' first.
*/

PRINT 'Begin CREAINDX.SQL'
GO

USE credit
SET NOCOUNT ON
GO
IF ( (SELECT db_name()) <> 'credit')
BEGIN
   RAISERROR ('Database "credit" not found.',22,1) WITH LOG
END
GO


/*    
**  Record the time.
*/

SELECT 'began' = getdate() INTO #starttime
GO



/*
**  Drop the old indexes.
*/

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'provider_region_link')
  DROP INDEX  provider.provider_region_link

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'corporation_region_link')
  DROP INDEX  corporation.corporation_region_link

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'member_region_link')
  DROP INDEX  member.member_region_link

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'member_corporation_link')
  DROP INDEX  member.member_corporation_link

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'statement_member_link')
  DROP INDEX  statement.statement_member_link

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'payment_member_link')
  DROP INDEX  payment.payment_member_link

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'charge_category_link')
  DROP INDEX  charge.charge_category_link

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'charge_provider_link')
  DROP INDEX  charge.charge_provider_link

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'charge_member_link')
  DROP INDEX  charge.charge_member_link

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'charge_statement_link')
  DROP INDEX  charge.charge_statement_link

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'charge_charge_amt')
  DROP INDEX  charge.charge_charge_amt
GO



/*
**  Create Entity tables (region, provider, corp, member) foreign key indexes.
*/

CREATE INDEX provider_region_link ON provider (region_no) 
GO

CREATE INDEX corporation_region_link ON corporation (region_no)
GO

CREATE INDEX member_region_link ON member (region_no)
GO

CREATE INDEX member_corporation_link ON member (corp_no)
GO



/*
**  Create Transaction tables (charge, statement, payment) foreign key indexes.
*/

CREATE INDEX statement_member_link ON statement (member_no)
GO

CREATE INDEX payment_member_link ON payment (member_no)
GO

CREATE INDEX charge_member_link ON charge (member_no, charge_no)
GO

CREATE INDEX charge_category_link ON charge (category_no)
GO

CREATE INDEX charge_provider_link ON charge (provider_no)
GO

CREATE INDEX charge_statement_link ON charge (statement_no)
GO

CREATE INDEX charge_charge_amt ON charge (charge_amt)
GO



DECLARE 
  @message char(255), 
  @began datetime  
SELECT @began = began from #starttime
SELECT ' ' = ' '
SELECT @message = 
  'Time (in minutes:seconds) to CREATE FOREIGN KEY INDEXES ' + 
  convert( char(2), datediff(ss,@began,getdate())/60 ) + 
  ':' + 
   convert( char(2), datediff(ss,@began,getdate())%60 )    
RAISERROR(@message, 10, 1)
SELECT ' ' = ' '
GO


/*
**  Truncate the log.
*/

BACKUP TRANSACTION credit WITH TRUNCATE_ONLY
GO
