-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-- Written by Kimberly L. Tripp - all rights reserved.
-- 
-- For more scripts and sample code, check out 
-- 	http://www.SQLSkills.com
-- For "More than Just Training," see the Industry Experts at 
-- 	http://www.SolidQualityLearning.com
--
-- Disclaimer - Thoroughly test this script, execute at your own risk.
-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

USE Credit
go
-- DROP INDEX Charge.charge_charge_Amt
-- DROP INDEX Charge.Covering1
-- DROP INDEX Charge.Covering2
go

SELECT count(*) FROM charge
go

SELECT MAX(charge_amt) FROM charge
go
set statistics io on
SELECT * FROM charge 
	WHERE charge_amt > 6000
go -- 0 ROWS... 9305 IOs (Table Scan)

ALTER TABLE charge
ADD CONSTRAINT ChargeChargeAmtCKCnstIsTrusted
	CHECK (charge_amt < 5010)
go

SELECT * FROM charge 
	WHERE charge_amt > 6000
go -- 0 ROWS... 0 IOs 

ALTER TABLE charge
	DROP CONSTRAINT ChargeChargeAmtCKCnstIsTrusted
go

ALTER TABLE charge
	WITH NOCHECK -- This is evil :)
ADD CONSTRAINT ChargeChargeAmtCKCnstIsNOTTrusted
	CHECK (charge_amt < 5010)
go

SET STATISTICS IO ON
-- BACK TO A SCAN...don't use WITH NOCHECK!
SELECT * FROM charge 
	WHERE charge_amt > 6000
go -- 0 ROWS... 9305 IOs (Table Scan)

-- Even if you use DBCC CHECKCONSTRAINTS and NO data fails verification...
-- the data is NOT truly verified (the optimizer will NOT trust the constraint)

-- To verify data
SELECT OBJECTPROPERTY(object_id('ChargeChargeAmtCK'), 'ChargeChargeAmtCKCnstIsNOTTrusted') 
-- should be 1 because the constraint is not trusted...
go
DBCC CHECKCONSTRAINTS('charge')
go
SELECT OBJECTPROPERTY(object_id('ChargeChargeAmtCK'), 'ChargeChargeAmtCKCnstIsNOTTrusted') 
go

-- Even if the data did not produce errors it's still NOT trusted because only the create 
-- with CHECK properly sets this bit!
-- IF you absolutely want the data consistency issues of having a check constraint WITHOUT the 
-- "downtime" of having to do a table lock then you can add the constraint with NOCHECK (at 10am
-- on a Monday morning, for example) and then SCHEDULE an off hours DROP/re-CREATE of the 
-- constraint. This will ensure that the optimizer properly uses the constraint wherever it can!