                                                                /*    GENSDAT1.SQL   */
/*       
**
**  This script loads some of the sample data for the Credit database.
**
**  All data that is randomly generated, such as members and charges, is generated in
**  GENSDAT1.DAT.  For performance reasons, GENSDAT1.DAT is run before the indexes
**  are built.  All data that is generated by running standard stored procedures,
**  such as statements and payments, is generated in GENSDAT2.SQL, which is run after
**  the indexes have been build.
**  
**  You must have submitted the GENSTBLS.SQL and GENSPROC.SQL scripts first.
**  
*/



--  Don't forget to say 'USE Credit' first.

USE Credit
SET NOCOUNT ON
GO
IF ( (SELECT db_name()) <> 'Credit')
BEGIN
   RAISERROR ('Database "Credit" not found.',22,127) WITH LOG
END
GO


PRINT 'Begin GENSDAT1.SQL'
GO

SELECT 'began' = getdate() INTO #starttime
GO



--  Load regions

EXEC addregion
    @region_name      = 'North American'
  , @street           = '111 First St.'
  , @city             = 'Toronto'
  , @state_prov       = 'ON'
  , @country          = 'Canada'
  , @mail_code        = '  '
  , @phone_no         = '  '


EXEC addregion
    @region_name      = 'South American'
  , @street           = '222 Second St.'
  , @city             = 'Sao Paulo'
  , @state_prov       = '  '
  , @country          = 'Brazil'
  , @mail_code        = '  '
  , @phone_no         = '  '


EXEC addregion
    @region_name      = 'Scandanavian'
  , @street           = '333 Third St.'
  , @city             = 'Goteborg'
  , @state_prov       = '  '
  , @country          = 'Sweden'
  , @mail_code        = '  '
  , @phone_no         = '  '


EXEC addregion
    @region_name      = 'Western European'
  , @street           = '444 Fourth St.'
  , @city             = 'Brussels'
  , @state_prov       = '  '
  , @country          = '  '
  , @mail_code        = '  '
  , @phone_no         = '  '


EXEC addregion
    @region_name      = 'Eastern European'
  , @street           = '555 Fifth St St.'
  , @city             = 'Budapest'
  , @state_prov       = '  '
  , @country          = '  '
  , @mail_code        = '  '
  , @phone_no         = '  '


EXEC addregion
    @region_name      = 'Japan'
  , @street           = '666 Sixth'
  , @city             = 'Tokyo'
  , @state_prov       = '  '
  , @country          = 'Japan'
  , @mail_code        = '  '
  , @phone_no         = '  '


EXEC addregion
    @region_name      = 'China'
  , @street           = '777 Seventh St'
  , @city             = 'Beijing'
  , @state_prov       = '  '
  , @country          = '  '
  , @mail_code        = '  '
  , @phone_no         = '  '


EXEC addregion
    @region_name      = 'Mid East / South Asia'
  , @street           = '888 Eighth St.'
  , @city             = 'Madras'
  , @state_prov       = '  '
  , @country          = '  '
  , @mail_code        = '  '
  , @phone_no         = '  '


EXEC addregion
    @region_name      = 'Africa'
  , @street           = '999 Ninth St.'
  , @city             = 'Mombassa'
  , @state_prov       = '  '
  , @country          = 'Kenya'
  , @mail_code        = '  '
  , @phone_no         = '  '
GO



--  Load Categories

EXEC addcategory
    @category_desc    = 'Travel'

EXEC addcategory
    @category_desc    = 'Meals'

EXEC addcategory
    @category_desc    = 'Lodging'

EXEC addcategory
    @category_desc    = 'Groceries'

EXEC addcategory
    @category_desc    = 'Entertainment'

EXEC addcategory
    @category_desc    = 'Clothing'

EXEC addcategory
    @category_desc    = 'Electronics'

EXEC addcategory
    @category_desc    = 'Home Supplies'

EXEC addcategory
    @category_desc    = 'Communication'

EXEC addcategory
    @category_desc    = 'Misc'
GO



--  Load Providers

DECLARE @no_of_regions smallint      SELECT @no_of_regions = COUNT(*) FROM region
DECLARE @no_of_iterations smallint   SELECT @no_of_iterations = COUNT(*) FROM corpname_table
DECLARE @curr_iteration smallint     SELECT @curr_iteration = 0

DECLARE @input_region_no numeric_id
DECLARE @input_name normstring

WHILE (@curr_iteration < @no_of_iterations)
BEGIN
   SELECT @curr_iteration = @curr_iteration + 1

   EXEC @input_region_no = skewed_rand @no_of_regions, 2
   SELECT @input_name = 'Prov. ' + (SELECT corpname FROM corpname_table WHERE int_key = @curr_iteration)

   EXEC addprovider
       @region_no        = @input_region_no
     , @provider_name    = @input_name
     , @street           = '  '
     , @city             = '  '
     , @state_prov       = '  '
     , @country          = '  '
     , @mail_code        = '  '
     , @phone_no         = '  '
END

DELETE provider 
  WHERE provider_no > 500
BACKUP LOG Credit WITH NO_LOG
GO



--  Load Corporations

DECLARE @no_of_regions smallint      SELECT @no_of_regions = COUNT(*) FROM region
DECLARE @no_of_iterations smallint   SELECT @no_of_iterations = COUNT(*) FROM corpname_table
DECLARE @curr_iteration smallint     SELECT @curr_iteration = 0
DECLARE @input_expr_dt datetime      SELECT @input_expr_dt = DATEADD(YEAR,5,getdate())

DECLARE @input_region_no numeric_id
DECLARE @input_name normstring

WHILE (@curr_iteration < @no_of_iterations)
BEGIN
   SELECT @curr_iteration = @curr_iteration + 1

   SELECT @input_region_no = (RAND() * (@no_of_regions - 1)) + 1
   SELECT @input_name = 'Corp. ' + (SELECT corpname FROM corpname_table WHERE int_key = @curr_iteration)

   EXEC addcorporation
       @region_no        = @input_region_no
     , @corp_name        = @input_name
     , @street           = '  '
     , @city             = '  '
     , @state_prov       = '  '
     , @country          = '  '
     , @mail_code        = '  '
     , @phone_no         = '  '
     , @expr_dt          = @input_expr_dt
END

DELETE corporation 
  WHERE corp_no > 1000
BACKUP LOG Credit WITH NO_LOG
GO



--  Load members.

EXEC load_members 10001

DELETE member 
  WHERE member_no > 10000
BACKUP LOG Credit WITH NO_LOG
GO



--  Load charges

EXEC load_charges 100001

DELETE charge 
  WHERE charge_no > 200000
BACKUP LOG Credit WITH NO_LOG
GO



--  Get and display the elapsed time.

DECLARE 
  @message char(255), 
  @began datetime  
SELECT @began = began from #starttime
SELECT ' ' = ' '
SELECT @message = 
  'Time (in minutes:seconds) to LOAD DATA ' + 
  convert( char(2), datediff(ss,@began,getdate())/60 ) + 
  ':' + 
   convert( char(2), datediff(ss,@began,getdate())%60 )    
RAISERROR(@message, 10, 1)
SELECT ' ' = ' '
GO




